@@ -1,13 +1,11 @@
-// Copyright 2013-2018, The Gtk-rs Project Developers.
-// See the COPYRIGHT file at the top-level directory of this distribution.
-// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
+// Take a look at the license at the top of the repository in the LICENSE file.
 
-use atk_sys;
+use crate::EditableText;
 use glib::object::IsA;
 use glib::translate::*;
-use EditableText;
 
 pub trait EditableTextExtManual: 'static {
+    #[doc(alias = "atk_editable_text_insert_text")]
     fn insert_text(&self, string: &str, position: i32) -> i32;
 }
 
@@ -15,7 +13,7 @@ impl<O: IsA<EditableText>> EditableTextExtManual for O {
     fn insert_text(&self, string: &str, mut position: i32) -> i32 {
         let length = string.len() as i32;
         unsafe {
-            atk_sys::atk_editable_text_insert_text(
+            ffi::atk_editable_text_insert_text(
                 self.as_ref().to_glib_none().0,
                 string.to_glib_none().0,
                 length,
